@@ -1,6 +1,7 @@
 use crate::data::{Readout, ReadoutKey};
 use crate::theme::components::Palette;
-use crate::theme::theme::Theme;
+use crate::theme::components::PaletteType;
+use crate::theme::Theme;
 use std::collections::HashMap;
 use tui::buffer::Buffer;
 use tui::layout::{Margin, Rect};
@@ -79,16 +80,16 @@ impl<'a> Widget for ReadoutList<'a> {
         }
 
         let mut height = 0;
-        let keys = self.keys_to_text(&self.theme.get_key_color());
+        let keys = self.keys_to_text(self.theme);
         let max_key_width = Self::get_max_key_width(&keys);
         let themed_separator = Self::get_themed_separator(
-            &self.theme.get_separator(),
+            self.theme.get_separator(),
             &self.theme.get_separator_color(),
         );
 
         let mut max_line_width: u16 = 0;
 
-        for item in self.items.iter().filter(|f| f.1.is_ok()) {
+        for item in self.items.iter().filter(|&f| f.1.is_ok()) {
             //it's ok to unwrap, because we filtered out everything that is not a valid Option<T>.
             let readout_data = item.1.as_ref().unwrap();
             let readout_key = keys.get(&item.0).unwrap();
@@ -115,14 +116,18 @@ impl<'a> Widget for ReadoutList<'a> {
             }
 
             Paragraph::new(readout_key.clone()).render(*layout_iter.next().unwrap(), buf);
-            Paragraph::new(themed_separator.clone()).render(*layout_iter.next().unwrap(), buf);
+
+            if !self.theme.get_separator().is_empty() {
+                Paragraph::new(themed_separator.clone()).render(*layout_iter.next().unwrap(), buf);
+            }
+
             layout_iter.next();
             Paragraph::new(readout_data.to_owned()).render(*layout_iter.next().unwrap(), buf);
             height += readout_data.height() as u16;
         }
 
-        if let Some(palette) = self.theme.get_palette_type() {
-            self.print_palette(buf, &list_area, &mut height, palette);
+        if self.theme.get_palette().is_visible() {
+            self.print_palette(buf, &list_area, &mut height, self.theme.get_palette());
         }
 
         Self::render_block(
@@ -168,16 +173,23 @@ impl<'a> ReadoutList<'a> {
         ];
 
         let span_vector = |colors: &[Color]| -> Vec<_> {
-            colors
-                .iter()
-                .map(|c| Span::styled("   ", Style::default().bg(c.to_owned())))
-                .collect()
+            if let Some(glyph) = self.theme.get_palette().get_glyph() {
+                colors
+                    .iter()
+                    .map(|c| Span::styled(glyph.to_owned(), Style::default().fg(c.to_owned())))
+                    .collect()
+            } else {
+                colors
+                    .iter()
+                    .map(|c| Span::styled("   ", Style::default().bg(c.to_owned())))
+                    .collect()
+            }
         };
 
-        let spans = match palette {
-            Palette::Light => vec![Spans::from(span_vector(&light_colors))],
-            Palette::Dark => vec![Spans::from(span_vector(&dark_colors))],
-            Palette::Full => vec![
+        let spans = match palette.get_type() {
+            PaletteType::Light => vec![Spans::from(span_vector(&light_colors))],
+            PaletteType::Dark => vec![Spans::from(span_vector(&dark_colors))],
+            PaletteType::Full => vec![
                 Spans::from(span_vector(&dark_colors)),
                 Spans::from(span_vector(&light_colors)),
             ],
@@ -197,102 +209,13 @@ impl<'a> ReadoutList<'a> {
         *height += area.height + 1;
     }
 
-    fn keys_to_text(&self, key_color: &Color) -> HashMap<ReadoutKey, Text> {
-        let color_style = Style::default().fg(*key_color);
+    fn keys_to_text(&self, theme: &Theme) -> HashMap<ReadoutKey, Text> {
+        let style = Style::default().fg(theme.get_key_color());
 
-        let mut keys = HashMap::new();
-
-        keys.insert(
-            ReadoutKey::Host,
-            Text::styled(&self.theme.keys.host, color_style),
-        );
-
-        keys.insert(
-            ReadoutKey::Machine,
-            Text::styled(&self.theme.keys.machine, color_style),
-        );
-
-        keys.insert(
-            ReadoutKey::Kernel,
-            Text::styled(&self.theme.keys.kernel, color_style),
-        );
-
-        keys.insert(
-            ReadoutKey::Distribution,
-            Text::styled(&self.theme.keys.distro, color_style),
-        );
-
-        keys.insert(
-            ReadoutKey::OperatingSystem,
-            Text::styled(&self.theme.keys.os, color_style),
-        );
-
-        keys.insert(
-            ReadoutKey::DesktopEnvironment,
-            Text::styled(&self.theme.keys.de, color_style),
-        );
-
-        keys.insert(
-            ReadoutKey::WindowManager,
-            Text::styled(&self.theme.keys.wm, color_style),
-        );
-
-        keys.insert(
-            ReadoutKey::Packages,
-            Text::styled(&self.theme.keys.packages, color_style),
-        );
-
-        keys.insert(
-            ReadoutKey::Shell,
-            Text::styled(&self.theme.keys.shell, color_style),
-        );
-
-        keys.insert(
-            ReadoutKey::Terminal,
-            Text::styled(&self.theme.keys.terminal, color_style),
-        );
-
-        keys.insert(
-            ReadoutKey::LocalIP,
-            Text::styled(&self.theme.keys.local_ip, color_style),
-        );
-
-        keys.insert(
-            ReadoutKey::Battery,
-            Text::styled(&self.theme.keys.battery, color_style),
-        );
-
-        keys.insert(
-            ReadoutKey::Backlight,
-            Text::styled(&self.theme.keys.backlight, color_style),
-        );
-
-        keys.insert(
-            ReadoutKey::Resolution,
-            Text::styled(&self.theme.keys.resolution, color_style),
-        );
-
-        keys.insert(
-            ReadoutKey::Memory,
-            Text::styled(&self.theme.keys.memory, color_style),
-        );
-
-        keys.insert(
-            ReadoutKey::Processor,
-            Text::styled(&self.theme.keys.cpu, color_style),
-        );
-
-        keys.insert(
-            ReadoutKey::ProcessorLoad,
-            Text::styled(&self.theme.keys.cpu_load, color_style),
-        );
-
-        keys.insert(
-            ReadoutKey::Uptime,
-            Text::styled(&self.theme.keys.uptime, color_style),
-        );
-
-        keys
+        self.items
+            .iter()
+            .map(|i| (i.0, Text::styled(theme.key(&i.0).to_string(), style)))
+            .collect()
     }
 
     fn get_max_key_width(keys: &HashMap<ReadoutKey, Text>) -> usize {
@@ -333,12 +256,17 @@ impl<'a> ReadoutList<'a> {
         themed_separator: &Text,
         readout_data: &Text,
     ) -> Vec<u16> {
-        let mut values = vec![
-            max_key_width as u16 + self.theme.get_spacing() as u16,
-            themed_separator.width() as u16,
-            self.theme.get_spacing() as u16,
-            readout_data.width() as u16,
-        ];
+        let mut values = vec![];
+
+        if self.theme.get_separator().is_empty() {
+            values.push(max_key_width as u16);
+        } else {
+            values.push(max_key_width as u16 + self.theme.get_spacing() as u16);
+            values.push(themed_separator.width() as u16);
+        }
+
+        values.push(self.theme.get_spacing() as u16);
+        values.push(readout_data.width() as u16);
 
         if self.theme.get_padding() > 0 {
             values.insert(0, self.theme.get_padding() as u16)
